@@ -1,6 +1,4 @@
-from simple_ddl_parser.utils import check_spec
-
-from simple_ddl_parser.utils import remove_par
+from simple_ddl_parser.utils import check_spec, remove_par
 
 
 class HQL:
@@ -30,7 +28,6 @@ class HQL:
 
         p[0]["row_format"] = format
 
-
     def p_expression_with_serde(self, p):
         """expr : expr WITH SERDEPROPERTIES LP assigment RP"""
         p[0] = p[1]
@@ -42,13 +39,12 @@ class HQL:
     def p_expression_tblproperties(self, p):
         """expr : expr TBLPROPERTIES multi_assigments"""
         p[0] = p[1]
-        p_list = list(p)
         p[0]["tblproperties"] = list(p)[-1]
 
     def p_multi_assigments(self, p):
         """multi_assigments : LP assigment
-         | multi_assigments RP
-         | multi_assigments COMMA assigment RP"""
+        | multi_assigments RP
+        | multi_assigments COMMA assigment RP"""
         p_list = remove_par(list(p))
         p[0] = p_list[1]
         p[0].update(p_list[-1])
@@ -60,11 +56,11 @@ class HQL:
         |  STRING ID ID
         |  STRING ID"""
         p_list = remove_par(list(p))
-        if 'state' in self.lexer.__dict__:
+        if "state" in self.lexer.__dict__:
             p[0] = {p[1]: self.lexer.state.get(p_list[-1])}
         else:
-            if '=' in p_list[-1]:
-                p_list[-1] = p_list[-1].split('=')[-1]
+            if "=" in p_list[-1]:
+                p_list[-1] = p_list[-1].split("=")[-1]
             p[0] = {p_list[1]: p_list[-1]}
 
     def p_expression_comment(self, p):
@@ -89,6 +85,13 @@ class HQL:
         p_list = list(p)
         p[0]["map_keys_terminated_by"] = check_spec(p_list[-1])
 
+    def p_expression_skewed_by(self, p):
+        """expr : expr SKEWED BY LP ID RP ON LP pid RP
+        """
+        p[0] = p[1]
+        p_list = remove_par(list(p))
+        p[0]["skewed_by"] = {'key': p_list[4], 'on': p_list[-1]}
+
     def p_expression_collection_terminated_by(self, p):
         """expr : expr COLLECTION ITEMS TERMINATED BY ID
         | expr COLLECTION ITEMS TERMINATED BY STRING
@@ -98,17 +101,27 @@ class HQL:
         p[0]["collection_items_terminated_by"] = check_spec(p_list[-1])
 
     def p_expression_stored_as(self, p):
-        """expr : expr STORED AS ID"""
+        """expr : expr STORED AS ID
+        |  expr STORED AS ID STRING
+        |  expr STORED AS ID STRING ID STRING
+        """
         p[0] = p[1]
         p_list = list(p)
-        p[0]["stored_as"] = p_list[-1]
+        if len(p_list) >= 6:
+            # only input or output format
+            p[0]["stored_as"] = {p_list[-2].lower(): p_list[-1]}
+            if len(p_list) == 8:
+                # both input & output
+                p[0]["stored_as"].update({p_list[-4].lower(): p_list[-3]})
+        else:
+            p[0]["stored_as"] = p_list[-1]
 
     def p_expression_partitioned_by_hql(self, p):
         """expr : expr PARTITIONED BY pid_with_type """
         p[0] = p[1]
         p_list = list(p)
         p[0]["partitioned_by"] = p_list[-1]
-    
+
     def p_pid_with_type(self, p):
         """pid_with_type :  LP column
         | pid_with_type COMMA column
