@@ -2,8 +2,7 @@ import re
 from copy import deepcopy
 from typing import Dict, List
 
-from simple_ddl_parser.utils import remove_par
-from simple_ddl_parser.utils import check_spec
+from simple_ddl_parser.utils import check_spec, remove_par
 
 
 class AfterColumns:
