@@ -13,7 +13,7 @@ spec_mapper = {
     "'pars_m_t'": "'\t'",
     "'pars_m_n'": "'\n'",
     "'pars_m_dq'": '"',
-    "pars_m_single": '\''
+    "pars_m_single": "'",
 }
 
 
